FlutterImePlatform class abstract
Platform interface for Flutter IME plugin.
- Inheritance
-
- Object
- PlatformInterface
- FlutterImePlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onCapsLockChanged
→ Stream<
bool> -
Stream that emits when Caps Lock state changes.
no setter
-
onInputSourceChanged
→ Stream<
bool> -
Stream that emits when input source changes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableIME(
) → Future< void> - Disables IME (Windows only).
-
enableIME(
) → Future< void> - Enables IME (Windows only).
-
getCurrentInputSource(
) → Future< String?> - Gets the current input source as an opaque, platform-specific token (macOS and Windows). Callers must only round-trip it via setInputSource.
-
isCapsLockOn(
) → Future< bool> - Checks if Caps Lock is currently on.
-
isEnglishKeyboard(
) → Future< bool> - Checks if current IME is in English mode.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEnglishKeyboard(
) → Future< void> - Changes IME to English mode.
-
setInputSource(
String sourceId) → Future< void> - Restores an input source from an opaque token previously returned by getCurrentInputSource (macOS and Windows).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterImePlatform
-
Returns the default instance.
getter/setter pair